PyTables Release Notes — PyTables 3.1.1 documentation

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »

# PyTables Release Notes

## Migration

- Migrating from 2.x to 3.x
- Migrating from 1.x to 2.x

## PyTables

- Release notes for PyTables 3.1 series
- Release notes for PyTables 3.0 series
- Release notes for PyTables 2.4 series
- Release notes for PyTables 2.3 series
- Release notes for PyTables 2.2 series
- Release notes for PyTables 2.1 series
- Release notes for PyTables 2.0 series
- What’s new in PyTables 1.4
- What’s new in PyTables 1.3.3
- What’s new in PyTables 1.3.2
- What’s new in PyTables 1.3.1
- What’s new in PyTables 1.3
- What’s new in PyTables 1.2.3
- What’s new in PyTables 1.2.2
- What’s new in PyTables 1.2.1
- What’s new in PyTables 1.2
- What’s new in PyTables 1.1.1
- What’s new in PyTables 1.1
- What’s new in PyTables 1.0
- What’s new in PyTables 0.9.1
- What’s new in PyTables 0.9
- What’s new in PyTables 0.8
- What’s new in PyTables 0.7.2
- PyTables 0.7.1 is out!

## PyTables Pro

- Release notes for PyTables 2.2 series
- Release notes for PyTables 2.1 series
- Release notes for PyTables Pro 2.0 series

## Release timeline

PyTables | 3.1.1 | 2014-03-25
PyTables | 3.1.0 | 2014-02-05
PyTables | 3.1.0rc2 | 2014-01-22
PyTables | 3.1.0rc1 | 2014-01-17
PyTables | 3.0 | 2013-06-01
PyTables | 3.0rc3 | 2013-05-29
PyTables | 3.0rc2 | 2013-05-17
PyTables | 3.0rc1 | 2013-05-10
PyTables | 3.0b1 | 2013-04-27
PyTables | 2.4 | 2012-07-20
PyTables | 2.4rc1 | 2012-07-16
PyTables | 2.4b1 | 2012-07-07
PyTables | 2.3.1 | 2011-10-28
PyTables | 2.3 | 2011-09-23
PyTables | 2.3rc1 | 2011-09-11
PyTables | 2.2.1 | 2010-11-05
PyTables | 2.2.1rc1 | 2010-11-03
Pytables | 2.2 | 2010-07-01
PyTables | 2.2rc2 | 2010-06-17
PyTables | 2.2rc1 | 2010-05-20
PyTables | 2.1.2 | 2009-09-14
PyTables | 2.1.1 | 2009-03-13
PyTables Pro | 2.1.1 | 2009-03-13
PyTables | 2.1 | 2008-12-19
PyTables | 2.1rc2 | 2008-11-18
PyTables | 2.1rc1 | 2008-10-31
PyTables | 2.0.4 | 2008-07-05
PyTables Pro | 2.0.4 | 2008-07-05
PyTables | 2.0.3 | 2008-03-07
PyTables Pro | 2.0.2.1 | 2007-12-24
PyTables Pro | 2.0.1 | 2007-09-20
PyTables | 2.0.1 | 2007-09-20
PyTables Pro | 2.0 | 2007-07-12
PyTables | 2.0 | 2007-07-12
PyTables | 2.0rc2 | 2007-05-28
PyTables | 2.0rc1 | 2007-04-26
PyTables | 1.4 | 2006-12-21
PyTables | 1.3.3 | 2006-08-24
PyTables | 1.3.2 | 2006-06-20
PyTables | 1.3.1 | 2006-05-02
PyTables | 1.3 | 2006-04-01
PyTables | 1.2.3 | 2006-02-23
PyTables | 1.2.2 | 2006-02-16
PyTables | 1.2.1 | 2005-12-21
PyTables | 1.2 | 2005-11-22
PyTables | 1.1.1 | 2005-09-13
PyTables | 1.1 | 2005-07-14
PyTables | 1.0 | 2005-05-12
PyTables | 0.9.1 | 2004-12-02
PyTables- | 0.9 | 2004-11-08
PyTables | 0.8.1 | 2004-07-13
PyTables | 0.8 | 2004-03-03
PyTables | 0.7.2 | 2003-09-22
PyTables | 0.7 | 2003-07-31
PyTables | 0.5.1 | 2003-05-14
PyTables | 0.5 | 2003-05-10
Pytables | 0.4 | 2003-03-19

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »